import { ReactElement, useEffect, useContext } from "react";
import { Container, Row } from "react-bootstrap";
import { Link } from "react-router-dom";
import { Chart as ChartJS } from 'chart.js';

import PageHeader from "compendium/components/global/PageHeader"
import SectionNavigation from "compendium/components/SectionNavigation";
import OrganizationSidebar from "compendium/components/sidebar/OrganizationSidebar";
import PolicySidebar from "compendium/components/sidebar/PolicySidebar";
import ConnectedUsersSidebar from "compendium/components/sidebar/ConnectedUsersSidebar";
import NetworkSidebar from "compendium/components/sidebar/NetworkSidebar";
import ServicesSidebar from "compendium/components/sidebar/ServicesSidebar";
import DownloadDataButton from "compendium/components/download/DownloadDataButton";
import DownloadImageChartButton from "compendium/components/download/DownloadImageChartButton";

import useMatomo from "compendium/matomo/UseMatomo";

import { ExportType } from "compendium/helpers/constants";
import { Sections } from "compendium/helpers/constants";
import { PreviewContext } from "compendium/providers/PreviewProvider";
import { NrenAndYearDatapoint } from "compendium/Schema";

ChartJS.defaults.font.size = 16;
ChartJS.defaults.font.family = 'Open Sans';
ChartJS.defaults.font.weight = 700;

interface inputProps {
    title: string,
    description?: string | ReactElement,
    filter: ReactElement,
    children: ReactElement,
    category: Sections,
    data: NrenAndYearDatapoint[],
    filename: string,
}

function DataPage({ title, description, filter, children, category, data, filename }: inputProps): ReactElement {
    const { preview, setPreview } = useContext(PreviewContext);
    const locationWithoutPreview = window.location.origin + window.location.pathname;

    const { trackPageView } = useMatomo()

    useEffect(() => {
        trackPageView({
            documentTitle: title
        })
    }, [trackPageView, title])

    return (
        <>
            {category === Sections.Organisation && <OrganizationSidebar />}
            {category === Sections.Policy && <PolicySidebar />}
            {category === Sections.Network && <NetworkSidebar />}
            {category === Sections.ConnectedUsers && <ConnectedUsersSidebar />}
            {category === Sections.Services && <ServicesSidebar />}
            <PageHeader type={'data'} />
            {preview && <Row className="preview-banner">
                <span>You are viewing a preview of the website which includes pre-published survey data. <Link to={locationWithoutPreview} onClick={() => setPreview(false)}>Click here</Link> to deactivate preview mode.</span>
            </Row>}
            <SectionNavigation activeCategory={category} />
            <Container className="mb-5 grow">
                <Row>
                    <h3 className="m-1">{title}</h3>
                </Row>
                <Row>
                    <p className="p-md-4">{description}</p>
                </Row>

                <Row className="downloadcontainer">
                    <DownloadDataButton data={data} filename={`${filename}.csv`} exportType={ExportType.CSV} />
                    <DownloadDataButton data={data} filename={`${filename}.xlsx`} exportType={ExportType.EXCEL} />
                    <DownloadImageChartButton filename={filename} />
                </Row>
                <Row>
                    {filter}
                </Row>
                <Row>
                    {children}
                </Row>
            </Container>
        </>
    );
}

export default DataPage;