import React, { useContext } from "react";
import { AlienWaveInternal } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function AlienWaveInternalPage(): React.ReactElement {
    const dataField = 'alien_wave_internal';
    const validityCheck = (data: AlienWaveInternal) => data[dataField] !== null;

    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<AlienWaveInternal>('/api/alien-wave', setFilterSelection, validityCheck);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, dataField);

    const columns = [
        "Yes",
        "No",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "True"],
        [columns[1], "False"],
    ]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles["alien-wave-internal"]}
            description="The table below shows NREN usage of alien waves internally within their own networks. 
            This includes, for example, alien waves used between two equipment vendors, 
            eg. coloured optics on routes carried over DWDM (dense wavelength division multiplexing) equipment.

            In the optical network world, the term “alien wavelength” or “alien wave” (AW) is used to describe 
            wavelengths in a DWDM line system that pass through the network, i.e. they are not sourced/terminated 
            by the line-system operator’s equipment (hence “alien”). This setup is in contrast to traditional 
            DWDM systems, where the DWDM light source (transponder) operates in the same management domain 
            as the amplifiers."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="alien_wave_internal_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} columnLookup={columnValueMap} dataLookup={dataLookup} />
            </ChartContainer>
        </DataPage>
    );
}
export default AlienWaveInternalPage;
