import React, { useContext } from "react";

import { ExternalConnection } from "compendium/Schema";
import { createDataLookupList } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import { ScrollableTable } from "compendium/components/ScrollableTable";
import titles from "compendium/titles";

function ExternalConnectionsPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<ExternalConnection>('/api/external-connections', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year)
        && filterSelection.selectedNrens.includes(data.nren)
    );
    const dataLookup = createDataLookupList([...selectedData]);

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    // contains title for each column, and the field in the data object to look up for that column
    const columnInfo = {
        "Link Name": "link_name",
        "Capacity (Gbit/s)": "capacity",
        "From Organisation": "from_organization",
        "To Organisation": "to_organization",
        "Interconnection Method": "interconnection_method",
    }

    const description = <><p>The table below shows the operational external IP connections of each NREN.
        These include links to their regional backbone (ie. GÉANT), to other research locations,
        to the commercial internet, peerings to internet exchanges, cross-border dark fibre links, and any other links they may have.</p>
        <p>NRENs are asked to state the capacity for production purposes, not any additional link that may be there solely for the purpose of giving resilience.
            Cross-border fibre links are meant as those links which have been commissioned or established by the NREN from a point on their network,
            which is near the border to another point near the border on the network of a neighbouring NREN.</p></>

    return (
        <DataPage title={titles['external-connections']}
            description={description}
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="nren_external_connections">
            <ChartContainer>
                <ScrollableTable
                    dataLookup={dataLookup}
                    columnInfo={columnInfo}
                />
            </ChartContainer>
        </DataPage>
    );
}
export default ExternalConnectionsPage;
