import React, { useContext } from "react";
import { FibreLight } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function FibreLightPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<FibreLight>('/api/fibre-light', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'light_description');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const columns = [
        "NREN owns and operates equipment",
        "NREN owns equipment and operation is outsourced",
        "Ownership and management are out-sourced (turn-key model)",
    ]

    const columnValueMap = new Map<string, string>([
        [columns[0], "nren_owns_and_operates"],
        [columns[1], "nren_owns_outsourced_operation"],
        [columns[2], "outsourced_ownership_and_operation"],
    ]);

    return (
        <DataPage title={titles['fibre-light']}
            description="This graphic shows the different ways NRENs can light their fibre networks. 
            The option 'Other' is given, with extra information if you hover over the icon."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="fibre_light_of_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} dataLookup={dataLookup} columnLookup={columnValueMap} circle />
            </ChartContainer>
        </DataPage>
    );
}
export default FibreLightPage;
