import React, { useContext } from "react";

import { NetworkMapUrls } from "compendium/Schema";
import { createDataLookup, getTableData, getLatestData, extractUrls } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import NrenYearTable from "compendium/components/NrenYearTable";
import titles from "compendium/titles";

function NetworkMapUrlPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, nrens } = useData<NetworkMapUrls>('/api/network-map-urls', setFilterSelection);

    const latestData = data ? getLatestData(data) : [];
    const selectedData = latestData.filter(data =>
        filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createDataLookup(selectedData);

    const dataByYear = getTableData(dataLookup, (obj, trafficStatistics) => {
        const value = extractUrls(trafficStatistics);
        if (value == null) return;
        for (const [key, text] of Object.entries(value)) {
            obj[key] = text;
        }
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    return (
        <DataPage title={titles['network-map']}
            description="This table provides links to NREN network maps, showing layers 1, 2, and 3 of their networks."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="network_map_nrens_per_year">
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Network Map" dottedBorder noDots keysAreURLs removeDecoration />
            </ChartContainer>
        </DataPage>
    );
}
export default NetworkMapUrlPage;
