import React, { useContext } from "react";
import { SiemVendors } from "compendium/Schema";
import { createNrenTableLookup } from "compendium/helpers/dataconversion";
import DataPage from "compendium/components/DataPage";
import Filter from "compendium/components/graphing/Filter";
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from "compendium/providers/FilterSelectionProvider";
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from "compendium/helpers/useData";
import PillTable from "compendium/components/PillTable";
import titles from "compendium/titles";

function SiemVendorsPage(): React.ReactElement {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<SiemVendors>('/api/siem-vendors', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );

    const dataLookup = createNrenTableLookup(selectedData, 'vendor_names');

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
        coloredYears
    />

    const columns = [
        "Splunk",
        "IBM Qradar",
        "Exabeam",
        "LogRythm",
        "Securonix",
    ]

    return (
        <DataPage title={titles['siem-vendors']}
            description="The table below shows the kinds of vendors of SIEM/SOC systems used by NRENs."
            category={Sections.Network} filter={filterNode}
            data={selectedData} filename="siem_vendor_nrens_per_year">
            <ChartContainer>
                <PillTable columns={columns} dataLookup={dataLookup} circle />
            </ChartContainer>
        </DataPage>
    );
}
export default SiemVendorsPage;
