import { useContext } from 'react';

import { CorporateStrategy } from "compendium/Schema";
import { createDataLookup, getLatestData, getTableData } from 'compendium/helpers/dataconversion';
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import { useData } from 'compendium/helpers/useData';
import ChartContainer from 'compendium/components/graphing/ChartContainer';
import NrenYearTable from 'compendium/components/NrenYearTable';
import titles from "compendium/titles";

function CorporateStrategyPage() {
    const dataField = 'strategic_plan';
    const validityCheck = (data: CorporateStrategy) => !!data[dataField];

    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, nrens } = useData<CorporateStrategy>('/api/policy', setFilterSelection, validityCheck);

    const policyData = data ? getLatestData(data) : [];

    const selectedData = policyData.filter(policy =>
        filterSelection.selectedNrens.includes(policy.nren)
    );
    const policyDataByYear = createDataLookup(selectedData);

    const dataByYear = getTableData(policyDataByYear, (obj, strategy) => {
        const value = strategy[dataField];
        obj[value] = value;
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    return (
        <DataPage title={titles["corporate-strategy"]}
            description='The table below contains links to the NRENs most recent corporate strategic plans. 
            NRENs are asked if updates have been made to their corporate strategy over the previous year. 
            To avoid showing outdated links, only the most recent responses are shown.'
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename='nren_corporate_strategy'>
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Corporate Strategy" noDots keysAreURLs removeDecoration />
            </ChartContainer>
        </DataPage>
    )
}
export default CorporateStrategyPage;
