import { useContext } from 'react';

import { EOSCListing } from "compendium/Schema";
import { createDataLookupList, getTableData } from "compendium/helpers/dataconversion";
import DataPage from 'compendium/components/DataPage';
import Filter from "compendium/components/graphing/Filter"
import { Sections } from "compendium/helpers/constants";
import { FilterSelectionContext } from 'compendium/providers/FilterSelectionProvider';
import ChartContainer from "compendium/components/graphing/ChartContainer";
import { useData } from 'compendium/helpers/useData';
import NrenYearTable from 'compendium/components/NrenYearTable';
import titles from "compendium/titles";

// The data for this page is not good quality, so it's unlisted for now.

function EOSCListingsPage() {
    const { filterSelection, setFilterSelection } = useContext(FilterSelectionContext);
    const { data, years, nrens } = useData<EOSCListing>('/api/eosc-listings', setFilterSelection);

    const selectedData = data.filter(data =>
        filterSelection.selectedYears.includes(data.year) && filterSelection.selectedNrens.includes(data.nren)
    );
    const dataset = createDataLookupList(selectedData);

    const dataByYear = getTableData(dataset, (obj, EOSCListing) => {
        for (const listing of EOSCListing) {
            for (const serviceName of listing.service_names) {
                obj[serviceName] = serviceName;
            }
        }
    })

    const filterNode = <Filter
        filterOptions={{ availableYears: [...years], availableNrens: [...nrens.values()] }}
        filterSelection={filterSelection}
        setFilterSelection={setFilterSelection}
    />

    const description = <span>
        Some NRENs choose to list services on the EOSC portal, these can be seen in the table below.
        Click on the name of the NREN to expand the detail and see the names of the services they list.
    </span>

    return (
        <DataPage title={titles.eosc_listings}
            description={description}
            category={Sections.Policy} filter={filterNode}
            data={selectedData} filename='nren_eosc_listings'>
            <ChartContainer>
                <NrenYearTable data={dataByYear} columnTitle="Service Name" dottedBorder keysAreURLs noDots />
            </ChartContainer>
        </DataPage>
    );
}
export default EOSCListingsPage;
