interface ValidationQuestion {
    name?: string;
    value?: string | number | null;
    data?: ValidationQuestion;
}

function validateWebsiteUrl(value, nonEmpty = false) {
    if (!nonEmpty && (value == undefined || value == null || value == '')) {
        return true;
    }
    try {
        value = value.trim();
        if (value.includes(" ")) {
            return false;
        }
        // if there's not a protocol, add one for the test
        if (!value.includes(":/")) {
            value = "https://" + value;
        }
        const url = new URL(value);
        return !!url
    } catch {
        return false;
    }
}

// Overrides for questions that need to be validated differently from the default expression in their group
const questionOverrides = {
    data_protection_contact: (..._args) => true, // don't validate the contact field, anything goes..
}

export function validateQuestion(this: { question: ValidationQuestion, row?}, params) {
    try {
        const question = this.question;
        const validator = params[0] || undefined;

        const matrix = question.data && 'name' in question.data;

        let questionName;

        if (matrix) {
            questionName = question.data!.name;
        } else {
            questionName = question.name;
        }
        const value = question.value

        const hasOverride = questionOverrides[questionName];
        if (hasOverride) {
            return hasOverride(value, ...params.slice(1));
        }

        const validationFunction = validationFunctions[validator];
        if (!validationFunction) {
            throw new Error(`Validation function ${validator} not found for question ${questionName}`);
        }

        return validationFunction(value, ...params.slice(1));
    } catch (e) {
        console.error(e);
        return false;
    }
}

export function oldValidateWebsiteUrl(params) {
    let value = params[0];
    if ((value == undefined || value == null || value == '')) {
        return true;
    }
    try {
        value = value.trim();
        if (value.includes(" ")) {
            return false;
        }
        // if there's not a protocol, add one for the test
        if (!value.includes(":/")) {
            value = "https://" + value;
        }

        const url = new URL(value);
        return !!url
    } catch {
        return false;
    }
}

export const validationFunctions = {
    validateWebsiteUrl,
}